package logic

import (
	"context"

	"fusenapi/home-user-auth/internal/svc"
	"fusenapi/home-user-auth/internal/types"
	"fusenapi/model"
	"fusenapi/utils/auth"
	"fusenapi/utils/basic"

	"github.com/zeromicro/go-zero/core/logx"
)

type UserBasicInfoLogic struct {
	logx.Logger
	ctx    context.Context
	svcCtx *svc.ServiceContext
}

func NewUserBasicInfoLogic(ctx context.Context, svcCtx *svc.ServiceContext) *UserBasicInfoLogic {
	return &UserBasicInfoLogic{
		Logger: logx.WithContext(ctx),
		ctx:    ctx,
		svcCtx: svcCtx,
	}
}

func (l *UserBasicInfoLogic) UserBasicInfo(req *types.Request, userinfo *auth.UserInfo) (resp *types.Response) {
	// 必须返回response, 前端需要的是内部约定的Code码, 处理相关的逻辑. 例子(eg): resp.Set(501, "error")
	resp = &types.Response{}

	if userinfo.UserId == 0 {
		resp = &types.Response{
			Code:    510,
			Message: "user is not exists",
		}
		return resp
	}

	fsUserModel, err := model.NewFsUserModel(l.svcCtx.MysqlConn).FindOne(l.ctx, userinfo.UserId)
	if err != nil {
		logx.Error(err)
		resp.Set(510, err.Error())
		return resp
	}

	resp.SetStatus(basic.StatusOK, fsUserModel)
	return resp
}
